@@ -4,7 +4,7 @@
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
   There are special exceptions to the terms and conditions of the GPLv2 as it is applied to
-  this software, see the FLOSS License Exception
+  this software, see the FOSS License Exception
   <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
 
   This program is free software; you can redistribute it and/or modify it under the terms
@@ -25,45 +25,31 @@ package com.mysql.jdbc;
 
 /**
  * Assertions for empty code paths that should never be executed.
- * 
- * @author Mark Matthews
- * 
- * @version $Id: AssertionFailedException.java,v 1.1.2.1 2005/05/13 18:58:37
- *          mmatthews Exp $
  */
 public class AssertionFailedException extends RuntimeException {
 
-	private static final long serialVersionUID = 1L;
+    private static final long serialVersionUID = 1L;
 
-	// ~ Constructors
-	// -----------------------------------------------------------
+    /**
+     * Convenience method.
+     * 
+     * @param ex
+     *            the exception that should never have been thrown.
+     * @throws AssertionFailedException
+     *             for the exception ex.
+     */
+    public static void shouldNotHappen(Exception ex) throws AssertionFailedException {
+        throw new AssertionFailedException(ex);
+    }
 
-
-	/**
-	 * Convenience method.
-	 * 
-	 * @param ex
-	 *            the exception that should never have been thrown.
-	 * @throws AssertionFailedException
-	 *             for the exception ex.
-	 */
-	public static void shouldNotHappen(Exception ex)
-			throws AssertionFailedException {
-		throw new AssertionFailedException(ex);
-	}
-
-	// ~ Methods
-	// ----------------------------------------------------------------
-
-	/**
-	 * Creates an AssertionFailedException for the given exception that should
-	 * never have been thrown.
-	 * 
-	 * @param ex
-	 *            the exception that should never have been thrown.
-	 */
-	public AssertionFailedException(Exception ex) {
-		super(Messages.getString("AssertionFailedException.0") + ex.toString() //$NON-NLS-1$
-				+ Messages.getString("AssertionFailedException.1")); //$NON-NLS-1$
-	}
+    /**
+     * Creates an AssertionFailedException for the given exception that should
+     * never have been thrown.
+     * 
+     * @param ex
+     *            the exception that should never have been thrown.
+     */
+    public AssertionFailedException(Exception ex) {
+        super(Messages.getString("AssertionFailedException.0") + ex.toString() + Messages.getString("AssertionFailedException.1"));
+    }
 }
