@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2007, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -95,4 +95,11 @@ public interface Statement extends java.sql.Statement, Wrapper {
     public abstract int getOpenResultSetCount();
 
     public void setHoldResultsOpenOverClose(boolean holdResultsOpenOverClose);
+
+    /**
+     * Returns the id used when profiling
+     * 
+     * @return the id used when profiling.
+     */
+    int getId();
 }
