@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2017, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -435,4 +435,9 @@ public class MysqlDataSource extends ConnectionPropertiesImpl implements DataSou
     //	public <T> T unwrap(Class<T> iface) throws SQLException {
     //		throw SQLError.createSQLFeatureNotSupportedException();
     //	}
+
+    @Override
+    public Properties exposeAsProperties(Properties props) throws SQLException {
+        return exposeAsProperties(props, true);
+    }
 }
