@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2020, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -42,21 +42,21 @@ import java.sql.Time;
 import java.sql.Timestamp;
 import java.sql.Types;
 import java.text.SimpleDateFormat;
-import java.util.Locale;
 import java.util.Properties;
 
-import testsuite.BaseTestCase;
-
 import com.mysql.jdbc.CharsetMapping;
 import com.mysql.jdbc.MySQLConnection;
 import com.mysql.jdbc.NotImplemented;
 import com.mysql.jdbc.ParameterBindings;
 import com.mysql.jdbc.SQLError;
 import com.mysql.jdbc.StringUtils;
+import com.mysql.jdbc.TimeUtil;
 import com.mysql.jdbc.exceptions.MySQLStatementCancelledException;
 import com.mysql.jdbc.exceptions.MySQLTimeoutException;
 import com.mysql.jdbc.interceptors.ServerStatusDiffInterceptor;
 
+import testsuite.BaseTestCase;
+
 public class StatementsTest extends BaseTestCase {
     private static final int MAX_COLUMN_LENGTH = 255;
 
@@ -90,16 +90,16 @@ public class StatementsTest extends BaseTestCase {
 
         this.stmt.executeUpdate("DROP TABLE IF EXISTS statement_batch_test");
 
-        this.stmt
-                .executeUpdate("CREATE TABLE statement_test (id int not null primary key auto_increment, strdata1 varchar(255) not null, strdata2 varchar(255))");
+        this.stmt.executeUpdate(
+                "CREATE TABLE statement_test (id int not null primary key auto_increment, strdata1 varchar(255) not null, strdata2 varchar(255))");
 
         try {
             this.stmt.executeUpdate("CREATE TABLE statement_batch_test (id int not null primary key auto_increment, "
                     + "strdata1 varchar(255) not null, strdata2 varchar(255), UNIQUE INDEX (strdata1))");
         } catch (SQLException sqlEx) {
             if (sqlEx.getMessage().indexOf("max key length") != -1) {
-                createTable("statement_batch_test", "(id int not null primary key auto_increment, strdata1 varchar(175) not null, strdata2 varchar(175), "
-                        + "UNIQUE INDEX (strdata1))");
+                createTable("statement_batch_test",
+                        "(id int not null primary key auto_increment, strdata1 varchar(175) not null, strdata2 varchar(175), " + "UNIQUE INDEX (strdata1))");
             }
         }
 
@@ -777,6 +777,8 @@ public class StatementsTest extends BaseTestCase {
         Statement stmt2 = null;
         PreparedStatement pstmt2 = null;
 
+        ResultSet rs2 = null;
+
         try {
             stmt2 = conn2.createStatement();
 
@@ -805,10 +807,11 @@ public class StatementsTest extends BaseTestCase {
             this.rs = pstmt2.executeQuery();
             this.rs.next();
             this.rs.getInt(1);
-            pstmt2.executeQuery();
+            rs2 = pstmt2.executeQuery();
             this.rs.getInt(1);
             pstmt2.execute();
             this.rs.getInt(1);
+            rs2.close();
 
             pstmt2 = ((com.mysql.jdbc.Connection) conn2).clientPrepareStatement("SELECT 1");
             this.rs = pstmt2.executeQuery();
@@ -821,16 +824,17 @@ public class StatementsTest extends BaseTestCase {
             this.rs = pstmt2.executeQuery();
             this.rs.next();
             this.rs.getInt(1);
-            pstmt2.executeQuery();
+            rs2 = pstmt2.executeQuery();
             this.rs.getInt(1);
             pstmt2.execute();
             this.rs.getInt(1);
+            rs2.close();
 
             stmt2 = conn2.createStatement();
             this.rs = stmt2.executeQuery("SELECT 1");
             this.rs.next();
             this.rs.getInt(1);
-            stmt2.executeQuery("SELECT 2");
+            rs2 = stmt2.executeQuery("SELECT 2");
             this.rs.getInt(1);
             this.rs = stmt2.executeQuery("SELECT 1");
             this.rs.next();
@@ -839,6 +843,7 @@ public class StatementsTest extends BaseTestCase {
             this.rs.getInt(1);
             stmt2.execute("SET @var=2");
             this.rs.getInt(1);
+            rs2.close();
         } finally {
             if (stmt2 != null) {
                 stmt2.close();
@@ -863,7 +868,7 @@ public class StatementsTest extends BaseTestCase {
             // Test running a update for an query. It should fail.
             try {
                 this.conn.setAutoCommit(false);
-                this.stmt.executeQuery("UPDATE statement_test SET strdata1='blah' WHERE 1=0");
+                this.rs = this.stmt.executeQuery("UPDATE statement_test SET strdata1='blah' WHERE 1=0");
             } catch (SQLException sqlEx) {
                 assertTrue("Exception thrown for unknown reason", sqlEx.getSQLState().equalsIgnoreCase(SQLError.SQL_STATE_ILLEGAL_ARGUMENT));
             } finally {
@@ -1098,7 +1103,7 @@ public class StatementsTest extends BaseTestCase {
                 assertEquals(3, this.rs.getInt(1));
                 assertEquals(false, this.rs.next());
 
-                fetchStmt.executeQuery();
+                this.rs = fetchStmt.executeQuery();
             } finally {
                 if (fetchConn != null) {
                     fetchConn.close();
@@ -1280,12 +1285,11 @@ public class StatementsTest extends BaseTestCase {
 
             Object[][] differentTypes = new Object[1000][14];
 
-            createTable("rewriteBatchTypes", "(internalOrder int, f1 tinyint null, "
-                    + "f2 smallint null, f3 int null, f4 bigint null, "
-                    + "f5 decimal(8, 2) null, f6 float null, f7 double null, "
-                    + "f8 varchar(255) null, f9 text null, f10 blob null, f11 blob null, "
-                    + (versionMeetsMinimum(5, 6, 4) ? "f12 datetime(3) null, f13 time(3) null, f14 date null)"
-                            : "f12 datetime null, f13 time null, f14 date null)"));
+            createTable("rewriteBatchTypes",
+                    "(internalOrder int, f1 tinyint null, " + "f2 smallint null, f3 int null, f4 bigint null, "
+                            + "f5 decimal(8, 2) null, f6 float null, f7 double null, " + "f8 varchar(255) null, f9 text null, f10 blob null, f11 blob null, "
+                            + (versionMeetsMinimum(5, 6, 4) ? "f12 datetime(3) null, f13 time(3) null, f14 date null)"
+                                    : "f12 datetime null, f13 time null, f14 date null)"));
 
             for (int i = 0; i < 1000; i++) {
                 differentTypes[i][0] = Math.random() < .5 ? null : new Byte((byte) (Math.random() * 127));
@@ -1308,8 +1312,8 @@ public class StatementsTest extends BaseTestCase {
             props.setProperty("rewriteBatchedStatements", "true");
             props.setProperty("maxAllowedPacket", j == 0 ? "10240" : "1024");
             multiConn = getConnectionWithProps(props);
-            pStmt = multiConn.prepareStatement("INSERT INTO rewriteBatchTypes(internalOrder,f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f11,f12,f13,f14) VALUES "
-                    + "(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
+            pStmt = multiConn.prepareStatement(
+                    "INSERT INTO rewriteBatchTypes(internalOrder,f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f11,f12,f13,f14) VALUES " + "(?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
 
             for (int i = 0; i < 1000; i++) {
                 pStmt.setInt(1, i);
@@ -1346,7 +1350,7 @@ public class StatementsTest extends BaseTestCase {
 
             // We need to format this ourselves, since we have to strip the nanos off of TIMESTAMPs, so .equals() doesn't really work...
 
-            SimpleDateFormat sdf = new SimpleDateFormat("''yyyy-MM-dd HH:mm:ss''", Locale.US);
+            SimpleDateFormat sdf = TimeUtil.getSimpleDateFormat(null, "''yyyy-MM-dd HH:mm:ss''", null, null);
 
             while (this.rs.next()) {
                 for (int k = 0; k < 14; k++) {
@@ -1395,7 +1399,8 @@ public class StatementsTest extends BaseTestCase {
                         } else if (differentTypes[idx][k] instanceof Timestamp) {
                             assertEquals("On row " + idx + ", column " + (k + 1), sdf.format(differentTypes[idx][k]), sdf.format(this.rs.getObject(k + 1)));
                         } else if (differentTypes[idx][k] instanceof Double) {
-                            assertEquals("On row " + idx + ", column " + (k + 1), ((Double) differentTypes[idx][k]).doubleValue(), this.rs.getDouble(k + 1), .1);
+                            assertEquals("On row " + idx + ", column " + (k + 1), ((Double) differentTypes[idx][k]).doubleValue(), this.rs.getDouble(k + 1),
+                                    .1);
                         } else if (differentTypes[idx][k] instanceof Float) {
                             assertEquals("On row " + idx + ", column " + (k + 1), ((Float) differentTypes[idx][k]).floatValue(), this.rs.getFloat(k + 1), .1);
                         } else if (className.equals("java.lang.Byte")) {
@@ -1731,7 +1736,7 @@ public class StatementsTest extends BaseTestCase {
         for (int i = 0; i < valuesToTest.length; i++) {
             Object boundObject = bindings.getObject(i + 1);
 
-            if (boundObject == null && valuesToTest[i] == null) {
+            if (boundObject == null || valuesToTest[i] == null) {
                 continue;
             }
 
@@ -1753,12 +1758,18 @@ public class StatementsTest extends BaseTestCase {
         createTable("localInfileHooked", "(field1 int, field2 varchar(255))");
         String streamData = "1\tabcd\n2\tefgh\n3\tijkl";
         InputStream stream = new ByteArrayInputStream(streamData.getBytes());
+
+        Properties props = new Properties();
+        props.setProperty("allowLoadLocalInfile", "true");
+        Connection testConn = getConnectionWithProps(props);
+        Statement testStmt = testConn.createStatement();
+
         try {
-            ((com.mysql.jdbc.Statement) this.stmt).setLocalInfileInputStream(stream);
-            this.stmt.execute("LOAD DATA LOCAL INFILE 'bogusFileName' INTO TABLE localInfileHooked CHARACTER SET "
+            ((com.mysql.jdbc.Statement) testStmt).setLocalInfileInputStream(stream);
+            testStmt.execute("LOAD DATA LOCAL INFILE 'bogusFileName' INTO TABLE localInfileHooked CHARACTER SET "
                     + CharsetMapping.getMysqlCharsetForJavaEncoding(((MySQLConnection) this.conn).getEncoding(), (com.mysql.jdbc.Connection) this.conn));
             assertEquals(-1, stream.read());
-            this.rs = this.stmt.executeQuery("SELECT field2 FROM localInfileHooked ORDER BY field1 ASC");
+            this.rs = testStmt.executeQuery("SELECT field2 FROM localInfileHooked ORDER BY field1 ASC");
             this.rs.next();
             assertEquals("abcd", this.rs.getString(1));
             this.rs.next();
@@ -1766,7 +1777,8 @@ public class StatementsTest extends BaseTestCase {
             this.rs.next();
             assertEquals("ijkl", this.rs.getString(1));
         } finally {
-            ((com.mysql.jdbc.Statement) this.stmt).setLocalInfileInputStream(null);
+            ((com.mysql.jdbc.Statement) testStmt).setLocalInfileInputStream(null);
+            testConn.close();
         }
     }
 }
